# STICK TO SEMANTIC VERSIONING:
# https://semver.org/
# TLDR:
# Given a version number MAJOR.MINOR.PATCH, increment the:
#
# MAJOR version when you make incompatible API changes,
# MINOR version when you add functionality in a backwards compatible manner, and
# PATCH version when you make backwards compatible bug fixes.

# NEXT PERSON PLEASE: delete this comment and update the version to '3.23.1' or '3.24.0', removing the '.post2'
__version__ = "3.23.post2"
